@@ -6,6 +6,8 @@
 #'
 #' @return NULL
 #'
+#' @noRd
+#'
 #' @examples
 #'
 #' \dontrun{
@@ -17,7 +19,7 @@ print_menu <- function(chr_vector) {
 
   if (max_index == 0) {
 
-    stop("Error: The Character vector length must be greater than one.")
+    stop("Error: The Character vector length must be greater than one.", call. = FALSE)
 
   }
 
